@@ -1,15 +1,30 @@
 <?php
-// Set 403 Forbidden header immediately
-http_response_code(403);
+// We'll set the 403 header after checking everything loads properly
 
-require("/docker/whp/web/libs/security.php");
-require('/docker/whp/web/configs/config.php');
-require('/docker/whp/web/libs/network.php');
-require('/docker/whp/web/libs/security_manager.php');
+// Check if classes are already loaded by auto-prepend.php
+if (!class_exists('security_wrapper')) {
+    require("/docker/whp/web/libs/security.php");
+}
+if (!defined('DB_HOST')) {
+    require('/docker/whp/web/configs/config.php');
+}
+if (!class_exists('network_info')) {
+    require('/docker/whp/web/libs/network.php');
+}
+if (!class_exists('security_manager')) {
+    require('/docker/whp/web/libs/security_manager.php');
+}
 
-$SecMan = new security_wrapper();
-$NetInfo = new network_info();
-$SecManager = new security_manager();
+// Check if objects already exist from auto-prepend.php
+if (!isset($SecMan)) {
+    $SecMan = new security_wrapper();
+}
+if (!isset($NetInfo)) {
+    $NetInfo = new network_info();
+}
+if (!isset($SecManager)) {
+    $SecManager = new security_manager();
+}
 
 $client_ip = $NetInfo->get_client_ip();
 $blocked_info = $SecManager->is_ip_blocked($client_ip);
@@ -64,6 +79,9 @@ if (!empty($blocked_info['expires_at'])) {
 $service = !empty($blocked_info['service']) ? htmlspecialchars($blocked_info['service']) : 'Security System';
 $reason = !empty($blocked_info['reason']) ? htmlspecialchars($blocked_info['reason']) : 'Security violation detected';
 $failed_attempts = isset($blocked_info['failed_attempts']) ? $blocked_info['failed_attempts'] : 0;
+
+// Now set the 403 header before outputting HTML
+http_response_code(403);
 ?>
 <!DOCTYPE html>
 <html lang="en">
